# You can use this module if you want to ssh to network devices and execute commands on them.
# This Module is for DEVOPs.
# Author: David Johnnes
# email: david.johnnes@gmail.com
# Switzerland: JURA
